Boundless Life

Boundless Life

Download on the App Store
  • Ranking

    6th

    on Fitness

  • Favorites

    3,696

    Followers

  • Typical duration

    59 min

    per episode

  • If it hooks

    51%

    finish an episode

Based on Podcast App listening data

Boundless Life episodes

  • The Mold-Cancer Link, Resetting Your Nervous System, Dry Fasting, Nanonutrients & More With Ian Clark.
    I first met today's podcast guest at a health conference four years ago. I happened to be sitting across the dinner table from him, and watched as he pulled out the mysterious leather satchel that I'd seen him carrying all weekend long. He opened the satchel to reveal tiny bottles of black oil, dropper bottles full of dark, green algae-like goo, mineral salts, and all kinds of other strange substances which he proceeded to use to "dress-up" his dinner. Later, I learned his name - Ian Clark - and invited him on my podcast to talk about that green algae goo, which turned out to be marine phytoplankton. I also learned that back in 2004, at the age of 46, when he was hit with a series of life threatening health issues, obesity, and a prediction from physicians that he only had about two years left to live, Ian refused to accept life’s traditional circumstances and decided to pursue more natural methods of restoring perfect health. Ian began traveling all over the world to discover strange, new health products while developing relationships with top labs and researchers in the fields of natural healing. Now operating out of a farm in Canada with his five sons and the support of an entire team of innovators at Activation Products Canada and Activation Germany, his company has become a significant manufacturer of unique products like magnesium spray, black seed oil, marine phytoplankton and much more. In today's podcast with Ian, you'll discover: -The genetic illness that nearly killed Ian back in 2004 and led to his journey of interest in natural healing... -How you can personally "equip" your body to deal with mold and fungus (and the shocking link between mold, fungus and cancer)... -How Ian has created his own micro-universe to heal his body... -One specific pose you can hold for 30 minutes a day for two weeks to "reboot" your autonomic nervous system... -The small exercise machine that Ian swears by and keeps in both his home and his office... -A new form of fasting called "dry fasting"... -What Ian uses as a "smart drug" to stay hyper-awake and alert... -The reason Ian sprays his entire abdomen with magnesium prior to bed at night... -Why Ian travels everywhere with a black leather bag, and what he keeps in it... -And much more! Resources from this episode: -The Ultimate Superfood You've Probably Never Heard Of (previous phytoplankton podcast with Ian) -Activation Products -Dr. Simoncini mold/fungus -Tripping Over The Truth book on the metabolic theory -Fortis Construction -Concrobium mold control spray -Essential oils -Cold air diffuser -Dr. Stitler's website -Xiser Stairmaster -Dr. Filonov Dry Fasting resources Do you have questions, comments or feedback for Ian or I? Leave your thoughts at BenGreenfieldFitness.com and one of us will reply.
    1 hr 15 min
  • Kundalini Yoga, Cannabidiol, Psilocybin Mushrooms & More With Dr. Somer Nicole & James Radina.

    Last month, I had the pleasure of visiting Kauai, Hawaii and hanging out with a few of the coolest couples on the face of the planet. One such couple was big-wave surfer Laird Hamilton and his wife, volleyball Olympian and fitness celebrity Gabby Reece. You can listen to my podcast interview with them here.

    Another couple was James Sol Radina and Dr. Somer Nicole, who you get to meet in this podcast episode. Dr. Somer Nicole is a Doctor of Physical Therapy and specializes in CranioSacral Therapy, SomatoEmotional Release and is a Reiki Master/Teacher. She has teaches alignment-based Hatha Yoga and Kundalini Yoga, has been teaching Yoga since 2002 and travels internationally for workshops and retreats. She also creates personalized Yoga videos for clients, lives in Kauai and has created an online platform for Yoga, Meditation and holistic living you can access at www.YogaDoctors.TV. James Sol Radina, has been a podcast guest before in a special episode on CBD. He is CEO of EAD Labs, a co-founder of “The Science of Weed,” a documentary releasing in late 2016 that features over 40 of the top doctors and scientists on the subject of using cannabis for healing, has built a Hemp CBD product company that is the gold standard in the industry.

    My time with James and Somer in Hawaii included some groundbreaking personal discoveries into how to use kundalini yoga, experimentation with psilocybin, more insight into the science of CBD and much more.

    During our discussion, you'll discover:

    -How Somer and James met...

    -What Kundalini yoga actually is, and how it works from a scientific standpoint...

    -The difference between Kundalini breathing and Wim Hof breathing...

    -Why James does coconut oil pulling...

    -How to decide what a custom yoga routine should look or feel like...

    -Why James uses cannabidiol (CBD), and which forms he uses...

    -The surprising use that Somer has discovered for CBD, specifically for women...

    -Why James uses psilocybin micro-dosing...

    -The proposed mechanism of action of psilocybin...

    -What psilocybin can be "mixed" with to increase potency...

    -And much more!

    Resources from this episode: -Book "Tuning the Human Biofield: Healing with Vibrational Sound Therapy " -The movie "Neurons to Nirvana" -Earthrunner sandals -Ben's SmartDrugSmarts podcast episode on CBD -NatureCBD -Somer's custom yoga routines -My podcast episode with Wim Hof

    Do you have questions, comments, or feedback about anything that James, Somer and I discuss in this episode? Leave your thoughts at BenGreenfieldFitness.com and one of us will reply. And remember to click here if you want to one of Somer's custom yoga routines at a $65 discount!

    See omnystudio.com/listener for privacy information.

    1 hr 5 min
  • Sleep, Light, Alarms, Caffeine, Night Shifts, Naps, Sleeping Positions & More With Shawn Stevenson.

    Sleep can be super confusing. I get lots of questions about it and have my own too...for example: Are there healthy substitutes for sunlight? What does it exactly mean to be a fast vs. a slow caffeine metabolizer? What's the ideal nap length? How can you limit the damage from a night shift? What's the ideal sleeping position? Should you use an alarm?

    My guest on today's podcast is Shawn Stevenson just wrote the new book "Sleep Smarter: 21 Proven Tips to Sleep Your Way To a Better Body, Better Health and Bigger Success", and today we dig into plenty of detail on the topics he covers in this book, which I highly recommend as a comprehensive sleep resource.

    Shawn is a graduate of The University of Missouri - St. Louis, where he studied business, biology and kinesiology, and went on to be the founder of Advanced Integrative Health Alliance, a company that provides wellness services for individuals and organizations worldwide.

    Shawn has been featured in Entrepreneur magazine, Men's Health magazine, ESPN, FOX News, and many other media outlets. He is also a frequent keynote speaker for numerous organizations, universities, and conferences - all with outstanding reviews.

    To learn more about Shawn visit TheModelHealthShow.com.

    During our discussion, you'll discover: -How using natural medicine to rebuild his spine bones made Shawn want to write a book about sleep... -How Shawn and I differ in the ways we quantify and track sleep... -Whether there are sunlight substitutes you can use instead of sunlight... -How to measure your UVA vs. UVB exposure... -The difference between blue-light boxes, in-ear photo therapy and intranasal therapy... -How many sleep cycles you should get each night... -What Shawn thinks about the effect of caffeine on sleep if one is genetically tested and found to be a fast caffeine metabolizer... -Shawn's top tips for people who have to work graveyard or night shifts to avoid the metabolic issues that can arise with circadian rhythm disruptions... -The surprising link between gut bacteria and sleep... -Whether morning vs. evening exercise is best for sleep... -Shawn's thoughts on optimal nap time, and if you really need to limit your naps to less than 60 minutes... -What the ideal sleeping position is... -Why you should use black-out curtains and sleep masks even though your ancestors or "caveman" didn't... -The best type of alarm to use to optimize your sleep cycles... -And much more!

    Resources from this episode: -What You Need To Know About Stem Cells previous podcast episode with Shawn -The OURA ring and HRV Ben uses for sleep tracking (and other sleep cycle tips) -How to use light to "hack" your sleep cycles -Intranasal light therapy -Apps to measure your UVA/UVB index -My podcast with sleep coach Nick Littlehales -The Sleep Cocktail supplement -Dr J. Sleep Solution pillow

    Do you have questions, comments, or feedback for Shawn or I about what we discuss in this episode? Leave your thoughts at BenGreenfieldFitness.com and one of us will reply, and be sure to check out Shawn's book Sleep Smarter: 21 Proven Tips to Sleep Your Way To a Better Body, Better Health and Bigger Success.

    See omnystudio.com/listener for privacy information.

    1 hr 36 min
  • Sleep, Light, Alarms, Caffeine, Night Shifts, Naps, Sleeping Positions & More With Shawn Stevenson.
    Sleep can be super confusing. I get lots of questions
    about it and have my own too...for example: Are there
    healthy substitutes for sunlight? What does it exactly
    mean to be a fast vs. a slow caffeine metabolizer? What's
    the ideal nap length? How can you limit the damage from a
    night shift? What's the ideal sleeping position?
    Should you use an alarm?
    My guest on today's podcast is Shawn Stevenson just wrote the
    new book "Sleep
    Smarter: 21 Proven Tips to Sleep Your Way To a Better Body, Better
    Health and Bigger Success", and today we dig into plenty
    of detail on the topics he covers in this book, which I highly
    recommend as a comprehensive sleep resource.
    Shawn is a graduate of The University of Missouri - St. Louis,
    where he studied business, biology and kinesiology, and went
    on to be the founder of Advanced Integrative Health Alliance, a
    company that provides wellness services for individuals and
    organizations worldwide.
    Shawn has been featured in Entrepreneur magazine, Men's Health
    magazine, ESPN, FOX News, and many other media outlets. He is also
    a frequent keynote speaker for numerous organizations,
    universities, and conferences - all with outstanding reviews.
    To learn more about Shawn visit TheModelHealthShow.com.
    During our discussion, you'll discover:
    -How using natural medicine to rebuild his spine
    bones made Shawn want to write a book about sleep...
    -How Shawn and I differ in the ways we quantify
    and track sleep... -Whether there are sunlight
    substitutes you can use instead of sunlight... -How
    to measure your UVA vs. UVB exposure... -The difference
    between blue-light boxes, in-ear photo therapy and intranasal
    therapy... -How many sleep cycles you should get each
    night... -What Shawn thinks about the effect of
    caffeine on sleep if one is genetically tested and found to be
    a fast caffeine metabolizer... -Shawn's top tips for
    people who have to work graveyard or night shifts to avoid the
    metabolic issues that can arise with circadian rhythm
    disruptions... -The surprising link between gut
    bacteria and sleep... -Whether morning vs. evening
    exercise is best for sleep... -Shawn's thoughts on
    optimal nap time, and if you really need to limit your naps to less
    than 60 minutes... -What the ideal sleeping position
    is... -Why you should use black-out curtains and sleep
    masks even though your ancestors or "caveman" didn't...
    -The best type of alarm to use to optimize your sleep
    cycles... -And much more!
    Resources from this episode: -What You Need To Know About Stem Cells
    previous podcast episode with Shawn -The OURA ring and HRV Ben uses for sleep tracking
    (and other sleep cycle tips) -How to use light to "hack" your sleep cycles
    -Intranasal light therapy -Apps to measure your UVA/UVB index -My podcast with sleep coach Nick Littlehales
    -The Sleep Cocktail supplement -Dr J. Sleep Solution
    pillow
    Do you have questions, comments, or feedback for Shawn
    or I about what we discuss in this episode? Leave your thoughts at
    BenGreenfieldFitness.com and one of us will reply, and be
    sure to check out Shawn's book Sleep Smarter: 21 Proven
    Tips to Sleep Your Way To a Better Body, Better Health and Bigger
    Success.
    1 hr 41 min
  • Wine Myths, Dark & Dirty Secrets of the Wine Industry, Wine Biohacks & More!

    A few months ago, I released the article "Dark & Dirty Secrets Of The Wine Industry, Four Ways To Make Wine Healthier, and What Kind Of Wine Fit People Should Drink." 

    In it, I detailed the serious issues with arsenic, overpricing, lack of sustainability, high levels of sulfites, amines and ochratoxins, boatloads of sugars, high pH levels (that increase the possibility of contamination by unwanted organisms), a less than stellar taste, plastic polyethylenes and many other problems plaguing the modern wine industry - and causing many people (including my wife) to get headaches or poor sleep from a nightly glass of wine.

    At the end of that post, I highlight that I now drink a new kind of healthy wine called "FitVineWine", and in today's podcast, I interview Mark Warren, co-founder of FitVineWine, a national level black belt competitor in TaeKwonDo, a Crossfitter and of course, as a wine enthusiast and father of two boys, a man after my own heart.

    During our discussion, you'll discover:

    -Why there are shocking levels of additives and other fillers in most modern wines...

    -How most wineries add sugar and grape concentrate to wines to adjust the pH (and why pH is so important)...

    -Why many wines are filtered through wheat and contain gluten...

    -Whether you need to be concerned about mold in wine...

    -How you can concentrate the amount of antioxidants like resveratrol, polyphenols and proanthocyanidins in grapes...

    -What it means for a wine to be "biodynamic" or "organically" farmed...

    -Why many wines are over-irrigated and why wineries should use less water, not more...

    -Why wine grapes should be grown at higher, cooler elevations...

    -Why people really aren't allergic to sulfites in wine, and why it's something else altogether...

    -How FitVineWine compares to other popular "healthy" or "Paleo" wines out there...

    -And much more!

    Resources from this episode: -FitVineWine.com (use 10% discount code BEN10) “California Winemakers Sued Over High Levels of Arsenic in Wines” “Bad News for Those of You Who, Like Us, Drank Cheap Wine Each and Every Night of Your 20s” Do you have questions, comments or feedback for me or my guest Mark on anything we discuss in this episode? Leave your thoughts at BenGreenfieldFitness.com and one of us will reply...and click here to get a bottle of red or a bottle of white at FitVineWine.com with 10% discount code BEN10 (assuming you’re 21 years of age or older).

    See omnystudio.com/listener for privacy information.

    57 min
  • Wine Myths, Dark & Dirty Secrets of the Wine Industry, Wine Biohacks & More!
    A few months ago, I released the article "Dark & Dirty Secrets Of The Wine Industry, Four
    Ways To Make Wine Healthier, and What Kind Of Wine Fit People
    Should Drink." 
    In it, I detailed the serious issues with arsenic, overpricing,
    lack of sustainability, high levels of sulfites, amines and
    ochratoxins, boatloads of sugars, high pH levels (that increase the
    possibility of contamination by unwanted organisms), a less than
    stellar taste, plastic polyethylenes and many other problems
    plaguing the modern wine industry - and causing many people
    (including my wife) to get headaches or poor sleep from a nightly
    glass of wine.
    At the end of that post, I highlight that I now drink a new kind
    of healthy wine called "FitVineWine", and in today's podcast, I
    interview Mark Warren, co-founder of FitVineWine, a national level
    black belt competitor in TaeKwonDo, a Crossfitter and of course, as
    a wine enthusiast and father of two boys, a man after my own
    heart.
    During our discussion, you'll discover:
    -Why there are shocking levels of additives and other
    fillers in most modern wines...
    -How most wineries add sugar and grape concentrate to wines
    to adjust the pH (and why pH is so important)...
    -Why many wines are filtered through wheat and contain
    gluten...
    -Whether you need to be concerned about mold in
    wine...
    -How you can concentrate the amount of antioxidants like
    resveratrol, polyphenols and proanthocyanidins in
    grapes...
    -What it means for a wine to be "biodynamic" or
    "organically" farmed...
    -Why many wines are over-irrigated and why wineries should
    use less water, not more...
    -Why wine grapes should be grown at higher, cooler
    elevations...
    -Why people really aren't allergic to sulfites in wine,
    and why it's something else altogether...
    -How FitVineWine compares to other popular "healthy" or
    "Paleo" wines out there...
    -And much more!
    Resources from this episode: -FitVineWine.com
    (use 10% discount code BEN10) “California Winemakers Sued Over High Levels of
    Arsenic in Wines” “Bad News for Those of You Who, Like Us, Drank Cheap
    Wine Each and Every Night of Your 20s” Do you
    have questions, comments or feedback for me or my guest Mark on
    anything we discuss in this episode? Leave your thoughts at
    BenGreenfieldFitness.com and one of us will
    reply...and
    click here to get a bottle of red or a bottle of white at
    FitVineWine.com with 10% discount code BEN10 (assuming you’re 21
    years of age or older).
    1 hr 2 min
  • Nicotine Gum, Alactic Training, Binaural Beats, Small-Scale Farming & More With Robb Wolf.

    If you don't know who Robb Wolf is, you have probably been living either in a cave or at McDonald's.

    Robb is a former research biochemist and author of the New York Times Best Selling book "The Paleo Solution – The Original Human Diet".

    Robb has transformed the lives of hundreds of thousands of people around the world via his top ranked iTunes podcast, book and seminars. He has functioned as a review editor for the Journal of Nutrition and Metabolism, is co-founder of the nutrition and athletic training journal, The Performance Menu, co-owner of NorCal Strength & Conditioning, one of the Men’s Health “top 30 gyms in America” and he is a consultant for the Naval Special Warfare Resiliency program. He serves on the board of Directors/Advisors for Specialty Health Inc, Paleo FX, and Paleo Magazine.

    Robb is a former California State Powerlifting Champion (565 lb. Squat, 345 lb. Bench, 565 lb. Dead Lift) and a 6-0 amateur kickboxer. He coaches athletes at the highest levels of competition and consults with Olympians and world champions in MMA, motocross, rowing and triathlon. He has provided seminars in nutrition and strength & conditioning to a number of entities including NASA, Naval Special Warfare, the Canadian Light Infantry and the United States Marine Corps.

    In this episode, I dig into a day in the life of Robb, and reveal some the most important training, nutrition and biohacking tools he's been implement lately. During our discussion, you'll discover:

    -The details of Robb's Lazy Lobo ranch... -Robb's"dream" legit permaculture small farm setting for a family...

    -What Robb has found by experimenting with post-meal blood glucose monitoring and what he has found...

    -How to get the most strength training bang for your buck out of something called "alactic" sets...

    -Why Robb likes the "Versaclimber" so much... 

    -How Robb has been using binaural beats...

    -Robb's smart drug of choice...

    -Everything you need to know about using nicotine gum...

    -A never-before-revealed secret about Robb's new book he's writing...

    -And much more!

    Resources from this episode: -FlowerChecker app for plant identification -My Training At 44 -Brainwave app for binaural beats -Sleepstream app for binaural beats -My article on making your own smart drugs -GoodSense nicotine gum -WebMD piece on nicotine gum -"Healthy food" differ by individuality -Algorithm for genes that predict low-carb/high fat vs. high carb-low fat -Dexcom G5 blood glucose monitoring -PaleoFX 16 -Primal Endurance book by Mark Sisson -The Vasper exercise device -The Versaclimber

    Do you have questions, comments, or feedback for myself or Robb? Leave your thoughts at BenGreenfieldFitness.com and one of us will reply.

    See omnystudio.com/listener for privacy information.

    1 hr 3 min
  • Nicotine Gum, Alactic Training, Binaural Beats, Small-Scale Farming & More With Robb Wolf.
    If you don't know who Robb Wolf is, you have probably
    been living either in a cave or at McDonald's.
    Robb is a former research biochemist and author of the New York Times Best
    Selling book "The Paleo Solution – The Original Human
    Diet".
    Robb has transformed the lives of hundreds of thousands of
    people around the world via his top ranked iTunes podcast, book and
    seminars. He has functioned as a review editor for the Journal of
    Nutrition and Metabolism, is co-founder of the nutrition and
    athletic training journal, The Performance Menu, co-owner of NorCal
    Strength & Conditioning, one of the Men’s Health “top 30 gyms
    in America” and he is a consultant for the Naval Special Warfare
    Resiliency program. He serves on the board of Directors/Advisors
    for Specialty Health Inc, Paleo FX, and Paleo Magazine.
    Robb is a former California State Powerlifting Champion (565 lb.
    Squat, 345 lb. Bench, 565 lb. Dead Lift) and a 6-0 amateur
    kickboxer. He coaches athletes at the highest levels of competition
    and consults with Olympians and world champions in MMA, motocross,
    rowing and triathlon. He has provided seminars in nutrition and
    strength & conditioning to a number of entities including NASA,
    Naval Special Warfare, the Canadian Light Infantry and the United
    States Marine Corps.
    In this episode, I dig into a day in the life of Robb,
    and reveal some the most important training, nutrition and
    biohacking tools he's been implement lately. During our discussion,
    you'll discover:
    -The details of Robb's Lazy Lobo ranch...
    -Robb's"dream" legit permaculture small farm setting for a
    family...
    -What Robb has found by experimenting with post-meal blood
    glucose monitoring and what he has found...
    -How to get the most strength training bang for your buck
    out of something called "alactic" sets...
    -Why Robb likes the "Versaclimber" so much... 
    -How Robb has been using binaural beats...
    -Robb's smart drug of choice...
    -Everything you need to know about using nicotine
    gum...
    -A never-before-revealed secret about Robb's new book
    he's writing...
    -And much more!
    Resources from this episode: -FlowerChecker app for plant identification
    -My Training At 44 -Brainwave app for binaural beats -Sleepstream app for binaural beats -My article on making your own smart drugs
    -GoodSense
    nicotine gum -WebMD piece on nicotine gum -"Healthy food" differ by individuality
    -Algorithm for genes that predict low-carb/high
    fat vs. high carb-low fat -Dexcom G5
    blood glucose monitoring -PaleoFX 16 -Primal Endurance book by Mark Sisson -The Vasper exercise device -The Versaclimber
    Do you have questions, comments, or feedback for myself
    or Robb? Leave your thoughts at
    BenGreenfieldFitness.com and one of us will
    reply.
    1 hr 7 min
  • How To 20x Yourself: Training & Anti-Aging Secrets Of One Of The Most Bad-Ass Navy SEAL Coaches On The Face Of The Planet.

    This is a special bonus podcast episode with the guy you get to meet and hang out with if you come to the July 8, 9 and 10 SEALFit 20x event at my house!

    Two years ago, I reported on my experience at the brutal SEALFit Kokoro camp, a 60+ hour crucible you can read more about at "26 Mile Night Hikes, Surf Swim Torture, 450 Pound Giant Logs And More: What To Expect at SEALFit Kokoro Camp And 9 Ways To Get More Tough."

    In that article, I mention a guy named "Lance Cummings". Coach Lance's snarling face struck fear deep into the heart of every Kokoro participant in my class, and he is well known for being the man who dishes out extreme amounts of suffering and hardship for anybody brave enough to step into Kokoro.

    But there's much more to coach Lance Cummings than simply being a man who could kill you with his pinky finger.

    Technically, Lance is director of training at SEALFit.

    Before that, retired from Active Duty Navy Service with 30 years of combined Active and Reserve service. After graduating BUD/s Class 124 he deployed overseas in support of US Foreign Policy with six different SEAL teams on both the east and west coast. He served at the Naval Special Warfare Center as a Basic Underwater/SEAL (BUD/s) instructor where he earned his Master Training Specialist classification. He also worked several State Department Security Team contracts with private employers during his time in the Naval Reserves.

    He left Active Duty in 1995 to pursue a Doctorate of Chiropractic degree, graduating in 2000 from Life Chiropractic College in Atlanta. While running a Chiropractic practice in Ga. and continuing to serve in the SEAL Reserves, he was recalled to Active Duty in January 2002 to deploy to the Middle East in support of Operation Enduring Freedom in Afghanistan. He made 7 subsequent Middle East deployments to Afghanistan and Iraq with three different SEAL Teams as well as contracting with Blackwater Security.

    As the Training Officer at Naval Special Warfare Group 1, in charge of West Coast SEAL Team operational training and readiness, he helped establish the Human Performance Initiative, a tactical readiness assessment and evaluation testing system utilized by every SEAL team today.

    Since retiring from the Navy in 2011, Lance has coached at SEALFIT Integrative Training, where he, Mark Divine, and numerous SEALs and selected civilian coaches conduct multi-day Academies, 20X, Kokoro Camps and custom team events, both locally and internationally.

    His athletic accomplishments include hundreds of triathlons, multi-day adventure races (he once paddled from the Atlantic to the Pacific Ocean through the Panama Canal in 15 hours), endurance horse racing, and he has been a member of World Championship Teams in Military Pentathlon, Naval Pentathlon, Outrigger Canoe and Dragon Boat racing. He has won several Marksmanship awards in inter-service competition in both handgun and carbine categories, and also competes in Stand Up Paddle Board Racing, archery and mountain biking.

    He continues his passion for Chiropractic, both with people and animal patients. He is certified in Cold Laser Therapy, Functional Mobility, Thermal Imaging, and is a registered Emergency Medical Technician.   His wife is a practicing Emergency Physician, and he also has nine year old twins.

    His certifications and experiences include:

    Honor Graduate, US Army Master Fitness Trainer Academy SEAL Team Training Officer Certified Chiropractic Sports Physician NAUI Scuba Instructor US Navy Master Training Specialist Certified Veterinary Chiropractitioner Certified Strength and Conditioning Specialist Doctorate in Chiropractic, Life University, Marietta GA BS Education, Southern Illinois University American College of Sports Medicine Fitness Instructor TRX Suspension Training Level 1, 2 and Sports Rehabilitation Trainer Functional Movement Systems (FMS) Level II Certified Structural Functional Movement Assessment Certified US Military Pentathlon Athlete US Navy Pentathlon Athlete USA Mens Dragon Boat Team 2011, 2013, 2015 – Team physician and competitor Outrigger Canoe USA/World Championship Teams

    So the guy is a wealth of knowledge on not just survival and warfare, but also fitness, taking care of aging and injured bodies, pushing through pain and much more. During our discussion, you’ll discover:

    -What it feels like for Lance to be "the man" who strikes fear in the heart of all Kokoro participants...

    -When Lance decided he wanted to be a SEAL...

    -Whether Lance thinks he is simply "hardwired" differently from a genetics standpoint, or whether something happened during his childhood that made him a high achiever...

    -Why Lance got into pentathlon (and this crazy Brazilian penthathlon video)...

    -Lance's story of paddling from the Atlantic to the Pacific Ocean through the Panama Canal in 15 hours...

    -As one of the "fittest old dudes" I know, what Lance's fitness program look like... -How Lance pushes through pain...

    -The top tools Lance uses as a chiropractor - tools people know little about, but should when it comes to enhancing recovery or managing injuries...

    -What to expect at a SEALFit 20x event, and what can people expect at the Eastern Washington event at my house...

    -And much more!

    Resources from this episode: -The SEALFit 20x physical standards -Erchonia laser practitioner directory -"The Mindful Athlete" book by George Mumford -The TRX Suspension trainer that Lance swears by -FMS Functional Movement Systems -My three part series on SEALFit Academy & Kokoro -The SEALFit events page -SEALFit Kokoro -The upcoming SEALFit 20X course at Ben Greenfield's house

    Do you have questions, comments, or feedback about anything that coach Lance Cummings and I discuss in this episode? Leave your thoughts at BenGreenfieldFitness.com and one of us will reply. And remember to click here if you want to get in on the upcoming SEALFit 20X course at Ben Greenfield's house!

    See omnystudio.com/listener for privacy information.

    59 min
  • How To 20x Yourself: Training & Anti-Aging Secrets Of One Of The Most Bad-Ass Navy SEAL Coaches On The Face Of The Planet.
    This is a special bonus podcast episode
    with the guy you get to meet and hang out with if you come to
    the July 8, 9 and 10 SEALFit 20x event at my
    house!
    Two years ago, I reported on my experience at the brutal
    SEALFit Kokoro camp, a 60+ hour crucible you can read more about at
    "26 Mile Night Hikes, Surf Swim Torture, 450 Pound
    Giant Logs And More: What To Expect at SEALFit Kokoro Camp And 9
    Ways To Get More Tough."
    In that article, I mention a guy named "Lance Cummings".
    Coach Lance's snarling face struck fear deep into the heart of
    every Kokoro participant in my class, and he is well
    known for being the man who dishes out extreme amounts of suffering
    and hardship for anybody brave enough to step into
    Kokoro.
    But there's much more to coach Lance Cummings than simply being
    a man who could kill you with his pinky finger.
    Technically, Lance is director of training at SEALFit.
    Before that, retired from Active Duty Navy Service with 30
    years of combined Active and Reserve service. After graduating
    BUD/s Class 124 he deployed overseas in support of US Foreign
    Policy with six different SEAL teams on both the east and west
    coast. He served at the Naval Special Warfare Center as a Basic
    Underwater/SEAL (BUD/s) instructor where he earned his Master
    Training Specialist classification. He also worked several State
    Department Security Team contracts with private employers during
    his time in the Naval Reserves.
    He left Active Duty in 1995 to pursue a Doctorate of
    Chiropractic degree, graduating in 2000 from Life Chiropractic
    College in Atlanta. While running a Chiropractic practice in Ga.
    and continuing to serve in the SEAL Reserves, he was recalled to
    Active Duty in January 2002 to deploy to the Middle East in support
    of Operation Enduring Freedom in Afghanistan. He made 7 subsequent
    Middle East deployments to Afghanistan and Iraq with three
    different SEAL Teams as well as contracting with Blackwater
    Security.
    As the Training Officer at Naval Special Warfare Group 1, in
    charge of West Coast SEAL Team operational training and readiness,
    he helped establish the Human Performance Initiative, a tactical
    readiness assessment and evaluation testing system utilized by
    every SEAL team today.
    Since retiring from the Navy in 2011, Lance has coached at
    SEALFIT Integrative Training, where he, Mark Divine, and numerous
    SEALs and selected civilian coaches conduct multi-day Academies,
    20X, Kokoro Camps and custom team events, both locally and
    internationally.
    His athletic accomplishments include hundreds of triathlons,
    multi-day adventure races (he once paddled from the Atlantic to the
    Pacific Ocean through the Panama Canal in 15 hours), endurance
    horse racing, and he has been a member of World Championship Teams
    in Military Pentathlon, Naval Pentathlon, Outrigger Canoe and
    Dragon Boat racing. He has won several Marksmanship awards in
    inter-service competition in both handgun and carbine categories,
    and also competes in Stand Up Paddle Board Racing, archery and
    mountain biking.
    He continues his passion for Chiropractic, both with people and
    animal patients. He is certified in Cold Laser Therapy, Functional
    Mobility, Thermal Imaging, and is a registered Emergency Medical
    Technician.   His wife is a practicing Emergency Physician,
    and he also has nine year old twins.
    His certifications and experiences include:
    Honor Graduate, US Army Master Fitness Trainer
    Academy SEAL Team Training Officer Certified
    Chiropractic Sports Physician NAUI Scuba Instructor
    US Navy Master Training Specialist Certified
    Veterinary Chiropractitioner Certified Strength and
    Conditioning Specialist Doctorate in
    Chiropractic, Life University, Marietta GA BS
    Education, Southern Illinois University American College
    of Sports Medicine Fitness Instructor TRX Suspension
    Training Level 1, 2 and Sports Rehabilitation Trainer
    Functional Movement Systems (FMS) Level II Certified
    Structural Functional Movement Assessment Certified US
    Military Pentathlon Athlete US Navy Pentathlon
    Athlete USA Mens Dragon Boat Team 2011, 2013, 2015 – Team
    physician and competitor Outrigger Canoe USA/World
    Championship Teams
    So the guy is a wealth of knowledge on not just survival
    and warfare, but also fitness, taking care of aging and injured
    bodies, pushing through pain and much more. During our discussion,
    you’ll discover:
    -What it feels like for Lance to be "the man" who strikes
    fear in the heart of all Kokoro participants...
    -When Lance decided he wanted to be a SEAL...
    -Whether Lance thinks he is simply "hardwired" differently
    from a genetics standpoint, or whether something happened during
    his childhood that made him a high achiever...
    -Why Lance got into pentathlon (and this crazy
    Brazilian penthathlon video)...
    -Lance's story of paddling from the Atlantic to the Pacific
    Ocean through the Panama Canal in 15 hours...
    -As one of the "fittest old dudes" I know, what Lance's
    fitness program look like... -How Lance pushes through
    pain...
    -The top tools Lance uses as a chiropractor - tools people
    know little about, but should when it comes to enhancing
    recovery or managing injuries...
    -What to expect at a SEALFit 20x event, and what
    can people expect at the Eastern Washington event at my
    house...
    -And much more!
    Resources from this episode: -The SEALFit 20x physical standards -Erchonia
    laser practitioner directory -"The Mindful Athlete" book by George Mumford
    -The TRX
    Suspension trainer that Lance swears by -FMS Functional Movement Systems -My three part series on SEALFit Academy &
    Kokoro -The SEALFit events page -SEALFit Kokoro -The upcoming SEALFit 20X course at Ben Greenfield's
    house
    Do you have questions, comments, or feedback about
    anything that coach Lance Cummings and I discuss in this episode?
    Leave your thoughts at BenGreenfieldFitness.com and
    one of us will reply. And remember to click here if you want to get in
    on the upcoming SEALFit 20X course at Ben Greenfield's
    house!
    59 min

About Boundless Life

From the publisher's feed

Free fitness, nutrition, biohacking, fat loss, anti-aging and cutting-edge health advice from BenGreenfieldLife.com! Tune in to the latest research, interviews with exercise, diet and medical…

Best of Boundless Life

Ranked by our users in the last 21 days

More shows like Boundless Life

A HUMAN PROJECT by Wesley Chapman the Founder of A HUMAN PROJECT & Ryan Andrews: Talking hard hitting real issues to start a human conversation

A HUMAN PROJECT

176 Listeners

Dr. Ruscio Radio, DC: Health, Nutrition and Functional Healthcare by Dr. Michael Ruscio, DC

Dr. Ruscio Radio, DC: Health, Nutrition and Functional Healthcare

765 Listeners

Knowledge For Men by Andrew Ferebee

Knowledge For Men

672 Listeners

The Amy Porterfield Show by Amy Porterfield

The Amy Porterfield Show

4,585 Listeners

The Solopreneur Hour Podcast with Michael O'Neal by Michael O'Neal and Unemployable Co-Hosts

The Solopreneur Hour Podcast with Michael O'Neal

580 Listeners

Social Triggers Insider with Derek Halpern by Derek Halpern

Social Triggers Insider with Derek Halpern

363 Listeners

The Human Upgrade: Biohacking for Longevity & Performance by Dave Asprey

The Human Upgrade: Biohacking for Longevity & Performance

7,181 Listeners

The Model Health Show by Shawn Stevenson

The Model Health Show

7,222 Listeners

Onken's World Podcast by Nick Onken

Onken's World Podcast

141 Listeners

The Energy Blueprint Podcast by Ari Whitten

The Energy Blueprint Podcast

718 Listeners

The Genius Life by Max Lugavere

The Genius Life

4,872 Listeners

Dhru Purohit Show by Dhru Purohit

Dhru Purohit Show

3,422 Listeners

The Dr. Hyman Show by Dr. Mark Hyman

The Dr. Hyman Show

9,165 Listeners

Paul Saladino MD podcast by Paul Saladino, MD

Paul Saladino MD podcast

2,571 Listeners

The Ben Azadi Show by Ben Azadi

The Ben Azadi Show

1,089 Listeners

Ancient Health Podcast by Ancient Health Podcast

Ancient Health Podcast

1,777 Listeners

Dr. Jockers Functional Nutrition by Dr. Jockers

Dr. Jockers Functional Nutrition

845 Listeners

The Hunter Williams Podcast by Hunter Williams

The Hunter Williams Podcast

122 Listeners

LONGEVITY with Nathalie Niddam by Nathalie Niddam

LONGEVITY with Nathalie Niddam

294 Listeners

The Dr. Gabrielle Lyon Show by Dr. Gabrielle Lyon

The Dr. Gabrielle Lyon Show

1,190 Listeners

The Ultimate Human with Gary Brecka by Gary Brecka

The Ultimate Human with Gary Brecka

3,135 Listeners